(define-package "agda2-mode" "2.6.4.3"
  "interactive development for Agda, a dependently typed functional programming language"
  '((emacs "24.3"))) ;; dep defs for `annotation.el` and `eri.el` are not required if they are packaged together
